export var INFINITY = 1 / 0;
export var MAX_SAFE_INTEGER = Number.MAX_SAFE_INTEGER; // 9007199254740991;
export var MIN_SAFE_INTEGER = Number.MIN_SAFE_INTEGER;
export function toString(value) {
    return Object.prototype.toString.call(value);
}
export function toBoolean(value) {
    return !isNullOrUndefined(value) && value.toLowerCase() === "true";
}
export function keys(value) {
    return Object.keys(value);
}
export function values(object) {
    return Object.values(object);
}
export function isUpperCase(char) {
    return !isNullOrUndefined(char) && char === char.toUpperCase();
}
export function isLowerCase(char) {
    return !isNullOrUndefined(char) && char === char.toLowerCase();
}
export function isNumeric(value) {
    return !isNaN(value) && isNumber(value);
}
export function isNumber(value) {
    return toString(value) === "[object Number]";
}
export function isString(value) {
    return toString(value) === "[object String]";
}
export function isDate(value) {
    return toString(value) === "[object Date]";
}
export function isArray(value) {
    return toString(value) === "[object Array]";
}
export function isArguments(value) {
    return toString(value) === "[object Arguments]";
}
export function isUndefined(value) {
    return value === void 0;
}
export function isBoolean(value) {
    return (value === true || value === false || toString(value) === "[object Boolean]");
}
export function isNaN(value) {
    return isNumber(value) && Number.isNaN(value);
}
export function isNull(value) {
    return value === null;
}
export function toNumber(value, defaultn) {
    var num = Number(value);
    return isNumber(num) ? num : defaultn;
}
export function isObject(value) {
    var type = typeof value;
    return value != null && (type === "object" || type === "function");
}
// tslint:disable-next-line:ban-types
export function isFunction(value) {
    if (!isObject(value)) {
        return false;
    }
    var tag = toString(value);
    return (tag === "[object Function]" ||
        tag === "[object GeneratorFunction]" ||
        tag === "[object Proxy]");
}
export function isLength(value) {
    return (typeof value === "number" &&
        value > -1 &&
        value % 1 === 0 &&
        value <= MAX_SAFE_INTEGER);
}
export function isArrayLike(value) {
    return value != null && isLength(value.length) && !isFunction(value);
}
export function isNullOrUndefined(value) {
    return isUndefined(value) || isNull(value);
}
export function isEmpty(value) {
    if (isNullOrUndefined(value)) {
        return true;
    }
    if (isNumeric(value)) {
        return false;
    }
    if (isArrayLike(value) &&
        (isArray(value) || isString(value) || isArguments(value))) {
        return value.length === 0;
    }
    return keys(value).length === 0;
}
export function toPromise(promises, resolver) {
    return Promise.all(promises).then(resolver);
}
// tslint:disable-next-line:ban-types
export function conditional(condition, fn) {
    return function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return condition.apply(this, args) ? fn.apply(this, args) : void 0;
    };
}
export function isNative(object) {
    if (object instanceof Date) {
        return true;
    }
    else if (typeof File !== "undefined" && object instanceof File) {
        return true;
    }
    else if (typeof FormData !== "undefined" && object instanceof FormData) {
        return true;
    }
    return false;
}
export function replaceAll(source, search, replacement) {
    return source.split(search).join(replacement);
}
//# sourceMappingURL=common.js.map