"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.INFINITY = 1 / 0;
exports.MAX_SAFE_INTEGER = Number.MAX_SAFE_INTEGER; // 9007199254740991;
exports.MIN_SAFE_INTEGER = Number.MIN_SAFE_INTEGER;
function toString(value) {
    return Object.prototype.toString.call(value);
}
exports.toString = toString;
function toBoolean(value) {
    return !isNullOrUndefined(value) && value.toLowerCase() === "true";
}
exports.toBoolean = toBoolean;
function keys(value) {
    return Object.keys(value);
}
exports.keys = keys;
function values(object) {
    return Object.values(object);
}
exports.values = values;
function isUpperCase(char) {
    return !isNullOrUndefined(char) && char === char.toUpperCase();
}
exports.isUpperCase = isUpperCase;
function isLowerCase(char) {
    return !isNullOrUndefined(char) && char === char.toLowerCase();
}
exports.isLowerCase = isLowerCase;
function isNumeric(value) {
    return !isNaN(value) && isNumber(value);
}
exports.isNumeric = isNumeric;
function isNumber(value) {
    return toString(value) === "[object Number]";
}
exports.isNumber = isNumber;
function isString(value) {
    return toString(value) === "[object String]";
}
exports.isString = isString;
function isDate(value) {
    return toString(value) === "[object Date]";
}
exports.isDate = isDate;
function isArray(value) {
    return toString(value) === "[object Array]";
}
exports.isArray = isArray;
function isArguments(value) {
    return toString(value) === "[object Arguments]";
}
exports.isArguments = isArguments;
function isUndefined(value) {
    return value === void 0;
}
exports.isUndefined = isUndefined;
function isBoolean(value) {
    return (value === true || value === false || toString(value) === "[object Boolean]");
}
exports.isBoolean = isBoolean;
function isNaN(value) {
    return isNumber(value) && Number.isNaN(value);
}
exports.isNaN = isNaN;
function isNull(value) {
    return value === null;
}
exports.isNull = isNull;
function toNumber(value, defaultn) {
    var num = Number(value);
    return isNumber(num) ? num : defaultn;
}
exports.toNumber = toNumber;
function isObject(value) {
    var type = typeof value;
    return value != null && (type === "object" || type === "function");
}
exports.isObject = isObject;
// tslint:disable-next-line:ban-types
function isFunction(value) {
    if (!isObject(value)) {
        return false;
    }
    var tag = toString(value);
    return (tag === "[object Function]" ||
        tag === "[object GeneratorFunction]" ||
        tag === "[object Proxy]");
}
exports.isFunction = isFunction;
function isLength(value) {
    return (typeof value === "number" &&
        value > -1 &&
        value % 1 === 0 &&
        value <= exports.MAX_SAFE_INTEGER);
}
exports.isLength = isLength;
function isArrayLike(value) {
    return value != null && isLength(value.length) && !isFunction(value);
}
exports.isArrayLike = isArrayLike;
function isNullOrUndefined(value) {
    return isUndefined(value) || isNull(value);
}
exports.isNullOrUndefined = isNullOrUndefined;
function isEmpty(value) {
    if (isNullOrUndefined(value)) {
        return true;
    }
    if (isNumeric(value)) {
        return false;
    }
    if (isArrayLike(value) &&
        (isArray(value) || isString(value) || isArguments(value))) {
        return value.length === 0;
    }
    return keys(value).length === 0;
}
exports.isEmpty = isEmpty;
function toPromise(promises, resolver) {
    return Promise.all(promises).then(resolver);
}
exports.toPromise = toPromise;
// tslint:disable-next-line:ban-types
function conditional(condition, fn) {
    return function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return condition.apply(this, args) ? fn.apply(this, args) : void 0;
    };
}
exports.conditional = conditional;
function isNative(object) {
    if (object instanceof Date) {
        return true;
    }
    else if (typeof File !== "undefined" && object instanceof File) {
        return true;
    }
    else if (typeof FormData !== "undefined" && object instanceof FormData) {
        return true;
    }
    return false;
}
exports.isNative = isNative;
function replaceAll(source, search, replacement) {
    return source.split(search).join(replacement);
}
exports.replaceAll = replaceAll;
//# sourceMappingURL=common.js.map