"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var assign_1 = require("./assign");
function isMergeableObject(value) {
    var nonNullObject = value && typeof value === "object";
    return (nonNullObject &&
        Object.prototype.toString.call(value) !== "[object RegExp]" &&
        Object.prototype.toString.call(value) !== "[object Date]");
}
function emptyTarget(val) {
    return Array.isArray(val) ? [] : {};
}
function cloneIfNecessary(value, options) {
    return options.clone === true && isMergeableObject(value)
        ? deepmerge(emptyTarget(value), value, options)
        : value;
}
function defaultArrayMerge(target, source, options) {
    var destination = target.slice();
    source.forEach(function (e, i) {
        if (destination[i] === void 0) {
            destination[i] = cloneIfNecessary(e, options);
        }
        else if (isMergeableObject(e)) {
            destination[i] = deepmerge(target[i], e, options);
        }
        else if (target.indexOf(e) === -1) {
            destination.push(cloneIfNecessary(e, options));
        }
    });
    return destination;
}
function mergeObject(target, source, options) {
    var destination = {};
    if (isMergeableObject(target)) {
        Object.keys(target).forEach(function (key) {
            destination[key] = cloneIfNecessary(target[key], options);
        });
    }
    Object.keys(source).forEach(function (key) {
        var value = source[key];
        if (options.skipUndefined && value === void 0) {
            return;
        }
        if (!isMergeableObject(value) || !target[key]) {
            destination[key] = cloneIfNecessary(value, options);
        }
        else {
            destination[key] = deepmerge(target[key], value, options);
        }
    });
    return destination;
}
var defaults = {
    arrayMerge: defaultArrayMerge,
    clone: false,
    skipUndefined: false
};
function deepmerge(target, source, options) {
    if (source === void 0) { source = {}; }
    if (options === void 0) { options = {}; }
    var array = Array.isArray(source);
    var optionsx = assign_1.assign({}, defaults, options);
    var arrayMerge = options.arrayMerge;
    if (array) {
        return Array.isArray(target)
            ? arrayMerge(target, source, optionsx)
            : cloneIfNecessary(source, optionsx);
    }
    else {
        return mergeObject(target, source, optionsx);
    }
}
exports.deepmerge = deepmerge;
//# sourceMappingURL=merge.js.map